Class: Aws::KinesisAnalyticsV2::Types::AddApplicationOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::AddApplicationOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application to which you want to add the output configuration.
-
#current_application_version_id ⇒ Integer
The version of the application to which you want to add the output configuration.
-
#output ⇒ Types::Output
An array of objects, each describing one output configuration.
Instance Attribute Details
#application_name ⇒ String
The name of the application to which you want to add the output configuration.
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 210 class AddApplicationOutputRequest < Struct.new( :application_name, :current_application_version_id, :output) SENSITIVE = [] include Aws::Structure end |
#current_application_version_id ⇒ Integer
The version of the application to which you want to add the output configuration. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ‘ConcurrentModificationException` is returned.
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 210 class AddApplicationOutputRequest < Struct.new( :application_name, :current_application_version_id, :output) SENSITIVE = [] include Aws::Structure end |
#output ⇒ Types::Output
An array of objects, each describing one output configuration. In the output configuration, you specify the name of an in-application stream, a destination (that is, a Kinesis data stream, a Kinesis Data Firehose delivery stream, or an Amazon Lambda function), and record the formation to use when writing to the destination.
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 210 class AddApplicationOutputRequest < Struct.new( :application_name, :current_application_version_id, :output) SENSITIVE = [] include Aws::Structure end |