Class: Aws::KinesisAnalyticsV2::Types::AddApplicationReferenceDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::AddApplicationReferenceDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass AddApplicationReferenceDataSourceRequest data as a hash:
{
application_name: "ApplicationName", # required
current_application_version_id: 1, # required
reference_data_source: { # required
table_name: "InAppTableName", # required
s3_reference_data_source: {
bucket_arn: "BucketARN",
file_key: "FileKey",
},
reference_schema: { # required
record_format: { # required
record_format_type: "JSON", # required, accepts JSON, CSV
mapping_parameters: {
json_mapping_parameters: {
record_row_path: "RecordRowPath", # required
},
csv_mapping_parameters: {
record_row_delimiter: "RecordRowDelimiter", # required
record_column_delimiter: "RecordColumnDelimiter", # required
},
},
},
record_encoding: "RecordEncoding",
record_columns: [ # required
{
name: "RecordColumnName", # required
mapping: "RecordColumnMapping",
sql_type: "RecordColumnSqlType", # required
},
],
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an existing application.
-
#current_application_version_id ⇒ Integer
The version of the application for which you are adding the reference data source.
-
#reference_data_source ⇒ Types::ReferenceDataSource
The reference data source can be an object in your Amazon S3 bucket.
Instance Attribute Details
#application_name ⇒ String
The name of an existing application.
401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 401 class AddApplicationReferenceDataSourceRequest < Struct.new( :application_name, :current_application_version_id, :reference_data_source) SENSITIVE = [] include Aws::Structure end |
#current_application_version_id ⇒ Integer
The version of the application for which you are adding the reference data source. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the `ConcurrentModificationException` is returned.
401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 401 class AddApplicationReferenceDataSourceRequest < Struct.new( :application_name, :current_application_version_id, :reference_data_source) SENSITIVE = [] include Aws::Structure end |
#reference_data_source ⇒ Types::ReferenceDataSource
The reference data source can be an object in your Amazon S3 bucket. Kinesis Data Analytics reads the object and copies the data into the in-application table that is created. You provide an S3 bucket, object key name, and the resulting in-application table that is created.
401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 401 class AddApplicationReferenceDataSourceRequest < Struct.new( :application_name, :current_application_version_id, :reference_data_source) SENSITIVE = [] include Aws::Structure end |