Class: Aws::KinesisAnalyticsV2::Types::ApplicationCodeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ApplicationCodeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass ApplicationCodeConfiguration data as a hash:
{
code_content: {
text_content: "TextContent",
zip_file_content: "data",
s3_content_location: {
bucket_arn: "BucketARN", # required
file_key: "FileKey", # required
object_version: "ObjectVersion",
},
},
code_content_type: "PLAINTEXT", # required, accepts PLAINTEXT, ZIPFILE
}
Describes code configuration for an application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_content ⇒ Types::CodeContent
The location and type of the application code.
-
#code_content_type ⇒ String
Specifies whether the code content is in text or zip format.
Instance Attribute Details
#code_content ⇒ Types::CodeContent
The location and type of the application code.
536 537 538 539 540 541 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 536 class ApplicationCodeConfiguration < Struct.new( :code_content, :code_content_type) SENSITIVE = [] include Aws::Structure end |
#code_content_type ⇒ String
Specifies whether the code content is in text or zip format.
536 537 538 539 540 541 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 536 class ApplicationCodeConfiguration < Struct.new( :code_content, :code_content_type) SENSITIVE = [] include Aws::Structure end |