Class: Aws::KinesisAnalyticsV2::Types::ApplicationCodeConfigurationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ApplicationCodeConfigurationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass ApplicationCodeConfigurationUpdate data as a hash:
{
code_content_type_update: "PLAINTEXT", # accepts PLAINTEXT, ZIPFILE
code_content_update: {
text_content_update: "TextContent",
zip_file_content_update: "data",
s3_content_location_update: {
bucket_arn_update: "BucketARN",
file_key_update: "FileKey",
object_version_update: "ObjectVersion",
},
},
}
Describes code configuration updates for an application. This is supported for a Flink-based Kinesis Data Analytics application or a SQL-based Kinesis Data Analytics application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_content_type_update ⇒ String
Describes updates to the code content type.
-
#code_content_update ⇒ Types::CodeContentUpdate
Describes updates to the code content of an application.
Instance Attribute Details
#code_content_type_update ⇒ String
Describes updates to the code content type.
593 594 595 596 597 598 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 593 class ApplicationCodeConfigurationUpdate < Struct.new( :code_content_type_update, :code_content_update) SENSITIVE = [] include Aws::Structure end |
#code_content_update ⇒ Types::CodeContentUpdate
Describes updates to the code content of an application.
593 594 595 596 597 598 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 593 class ApplicationCodeConfigurationUpdate < Struct.new( :code_content_type_update, :code_content_update) SENSITIVE = [] include Aws::Structure end |