Class: Aws::KinesisAnalyticsV2::Types::ApplicationRestoreConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ApplicationRestoreConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass ApplicationRestoreConfiguration data as a hash:
{
application_restore_type: "SKIP_RESTORE_FROM_SNAPSHOT", # required, accepts SKIP_RESTORE_FROM_SNAPSHOT, RESTORE_FROM_LATEST_SNAPSHOT, RESTORE_FROM_CUSTOM_SNAPSHOT
snapshot_name: "SnapshotName",
}
Specifies the method and snapshot to use when restarting an application using previously saved application state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_restore_type ⇒ String
Specifies how the application should be restored.
-
#snapshot_name ⇒ String
The identifier of an existing snapshot of application state to use to restart an application.
Instance Attribute Details
#application_restore_type ⇒ String
Specifies how the application should be restored.
1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1289 class ApplicationRestoreConfiguration < Struct.new( :application_restore_type, :snapshot_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The identifier of an existing snapshot of application state to use to restart an application. The application uses this value if `RESTORE_FROM_CUSTOM_SNAPSHOT` is specified for the `ApplicationRestoreType`.
1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1289 class ApplicationRestoreConfiguration < Struct.new( :application_restore_type, :snapshot_name) SENSITIVE = [] include Aws::Structure end |