Class: Aws::KinesisAnalyticsV2::Types::CSVMappingParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::CSVMappingParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass CSVMappingParameters data as a hash:
{
record_row_delimiter: "RecordRowDelimiter", # required
record_column_delimiter: "RecordColumnDelimiter", # required
}
For a SQL-based Kinesis Data Analytics application, provides additional mapping information when the record format uses delimiters, such as CSV. For example, the following sample records use CSV format, where the records use the *'\n'* as the row delimiter and a comma (“,”) as the column delimiter:
`“name1”, “address1”`
`“name2”, “address2”`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#record_column_delimiter ⇒ String
The column delimiter.
-
#record_row_delimiter ⇒ String
The row delimiter.
Instance Attribute Details
#record_column_delimiter ⇒ String
The column delimiter. For example, in a CSV format, a comma (“,”) is the typical column delimiter.
1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1450 class CSVMappingParameters < Struct.new( :record_row_delimiter, :record_column_delimiter) SENSITIVE = [] include Aws::Structure end |
#record_row_delimiter ⇒ String
The row delimiter. For example, in a CSV format, *'\n'* is the typical row delimiter.
1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1450 class CSVMappingParameters < Struct.new( :record_row_delimiter, :record_column_delimiter) SENSITIVE = [] include Aws::Structure end |