Class: Aws::KinesisAnalyticsV2::Types::CheckpointConfigurationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Describes updates to the checkpointing parameters for a Flink-based Kinesis Data Analytics application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checkpoint_interval_updateInteger

Describes updates to the interval in milliseconds between checkpoint operations.

<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `CheckpointInterval` value of 60000, even if this value is set to another value using this API or in application code.

</note>

Returns:

  • (Integer)


1146
1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1146

class CheckpointConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :checkpointing_enabled_update,
  :checkpoint_interval_update,
  :min_pause_between_checkpoints_update)
  SENSITIVE = []
  include Aws::Structure
end

#checkpointing_enabled_updateBoolean

Describes updates to whether checkpointing is enabled for an application.

<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `CheckpointingEnabled` value of `true`, even if this value is set to another value using this API or in application code.

</note>

Returns:

  • (Boolean)


1146
1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1146

class CheckpointConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :checkpointing_enabled_update,
  :checkpoint_interval_update,
  :min_pause_between_checkpoints_update)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_type_updateString

Describes updates to whether the application uses the default checkpointing behavior of Kinesis Data Analytics. You must set this property to `CUSTOM` in order to set the `CheckpointingEnabled`, `CheckpointInterval`, or `MinPauseBetweenCheckpoints` parameters.

<note markdown=“1”> If this value is set to `DEFAULT`, the application will use the following values, even if they are set to other values using APIs or application code:

* **CheckpointingEnabled:** true
  • *CheckpointInterval:* 60000

  • *MinPauseBetweenCheckpoints:* 5000

</note>

Returns:

  • (String)


1146
1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1146

class CheckpointConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :checkpointing_enabled_update,
  :checkpoint_interval_update,
  :min_pause_between_checkpoints_update)
  SENSITIVE = []
  include Aws::Structure
end

#min_pause_between_checkpoints_updateInteger

Describes updates to the minimum time in milliseconds after a checkpoint operation completes that a new checkpoint operation can start.

<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `MinPauseBetweenCheckpoints` value of 5000, even if this value is set using this API or in application code.

</note>

Returns:

  • (Integer)


1146
1147
1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1146

class CheckpointConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :checkpointing_enabled_update,
  :checkpoint_interval_update,
  :min_pause_between_checkpoints_update)
  SENSITIVE = []
  include Aws::Structure
end