Class: Aws::KinesisAnalyticsV2::Types::CustomArtifactConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::CustomArtifactConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Specifies dependency JARs, as well as JAR files that contain user-defined functions (UDF).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
‘UDF` stands for user-defined functions.
-
#maven_reference ⇒ Types::MavenReference
The parameters required to fully specify a Maven reference.
-
#s3_content_location ⇒ Types::S3ContentLocation
For a Managed Service for Apache Flink application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Instance Attribute Details
#artifact_type ⇒ String
‘UDF` stands for user-defined functions. This type of artifact must be in an S3 bucket. A `DEPENDENCY_JAR` can be in either Maven or an S3 bucket.
1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1493 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |
#maven_reference ⇒ Types::MavenReference
The parameters required to fully specify a Maven reference.
1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1493 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |
#s3_content_location ⇒ Types::S3ContentLocation
For a Managed Service for Apache Flink application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1493 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |