Class: Aws::KinesisAnalyticsV2::Types::CustomArtifactConfigurationDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::CustomArtifactConfigurationDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Specifies a dependency JAR or a JAR of user-defined functions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
‘UDF` stands for user-defined functions.
-
#maven_reference_description ⇒ Types::MavenReference
The parameters that are required to specify a Maven dependency.
-
#s3_content_location_description ⇒ Types::S3ContentLocation
For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Instance Attribute Details
#artifact_type ⇒ String
‘UDF` stands for user-defined functions. This type of artifact must be in an S3 bucket. A `DEPENDENCY_JAR` can be in either Maven or an S3 bucket.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1520 class CustomArtifactConfigurationDescription < Struct.new( :artifact_type, :s3_content_location_description, :maven_reference_description) SENSITIVE = [] include Aws::Structure end |
#maven_reference_description ⇒ Types::MavenReference
The parameters that are required to specify a Maven dependency.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1520 class CustomArtifactConfigurationDescription < Struct.new( :artifact_type, :s3_content_location_description, :maven_reference_description) SENSITIVE = [] include Aws::Structure end |
#s3_content_location_description ⇒ Types::S3ContentLocation
For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1520 class CustomArtifactConfigurationDescription < Struct.new( :artifact_type, :s3_content_location_description, :maven_reference_description) SENSITIVE = [] include Aws::Structure end |