Class: Aws::KinesisAnalyticsV2::Types::DeployAsApplicationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::DeployAsApplicationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
The information required to deploy a Kinesis Data Analytics Studio notebook as an application with durable state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_content_location ⇒ Types::S3ContentBaseLocation
The description of an Amazon S3 object that contains the Amazon Data Analytics application, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Instance Attribute Details
#s3_content_location ⇒ Types::S3ContentBaseLocation
The description of an Amazon S3 object that contains the Amazon Data Analytics application, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1843 class DeployAsApplicationConfiguration < Struct.new( :s3_content_location) SENSITIVE = [] include Aws::Structure end |