Class: Aws::KinesisAnalyticsV2::Types::DiscoverInputSchemaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::DiscoverInputSchemaRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass DiscoverInputSchemaRequest data as a hash:
{
resource_arn: "ResourceARN",
service_execution_role: "RoleARN", # required
input_starting_position_configuration: {
input_starting_position: "NOW", # accepts NOW, TRIM_HORIZON, LAST_STOPPED_POINT
},
s3_configuration: {
bucket_arn: "BucketARN", # required
file_key: "FileKey", # required
},
input_processing_configuration: {
input_lambda_processor: { # required
resource_arn: "ResourceARN", # required
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_processing_configuration ⇒ Types::InputProcessingConfiguration
The InputProcessingConfiguration to use to preprocess the records before discovering the schema of the records.
-
#input_starting_position_configuration ⇒ Types::InputStartingPositionConfiguration
The point at which you want Kinesis Data Analytics to start reading records from the specified streaming source discovery purposes.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the streaming source.
-
#s3_configuration ⇒ Types::S3Configuration
Specify this parameter to discover a schema from data in an Amazon S3 object.
-
#service_execution_role ⇒ String
The ARN of the role that is used to access the streaming source.
Instance Attribute Details
#input_processing_configuration ⇒ Types::InputProcessingConfiguration
The InputProcessingConfiguration to use to preprocess the records before discovering the schema of the records.
3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3037 class DiscoverInputSchemaRequest < Struct.new( :resource_arn, :service_execution_role, :input_starting_position_configuration, :s3_configuration, :input_processing_configuration) SENSITIVE = [] include Aws::Structure end |
#input_starting_position_configuration ⇒ Types::InputStartingPositionConfiguration
The point at which you want Kinesis Data Analytics to start reading records from the specified streaming source discovery purposes.
3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3037 class DiscoverInputSchemaRequest < Struct.new( :resource_arn, :service_execution_role, :input_starting_position_configuration, :s3_configuration, :input_processing_configuration) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the streaming source.
3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3037 class DiscoverInputSchemaRequest < Struct.new( :resource_arn, :service_execution_role, :input_starting_position_configuration, :s3_configuration, :input_processing_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_configuration ⇒ Types::S3Configuration
Specify this parameter to discover a schema from data in an Amazon S3 object.
3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3037 class DiscoverInputSchemaRequest < Struct.new( :resource_arn, :service_execution_role, :input_starting_position_configuration, :s3_configuration, :input_processing_configuration) SENSITIVE = [] include Aws::Structure end |
#service_execution_role ⇒ String
The ARN of the role that is used to access the streaming source.
3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3037 class DiscoverInputSchemaRequest < Struct.new( :resource_arn, :service_execution_role, :input_starting_position_configuration, :s3_configuration, :input_processing_configuration) SENSITIVE = [] include Aws::Structure end |