Class: Aws::KinesisAnalyticsV2::Types::Input
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::Input
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass Input data as a hash:
{
name_prefix: "InAppStreamName", # required
input_processing_configuration: {
input_lambda_processor: { # required
resource_arn: "ResourceARN", # required
},
},
kinesis_streams_input: {
resource_arn: "ResourceARN", # required
},
kinesis_firehose_input: {
resource_arn: "ResourceARN", # required
},
input_parallelism: {
count: 1,
},
input_schema: { # required
record_format: { # required
record_format_type: "JSON", # required, accepts JSON, CSV
mapping_parameters: {
json_mapping_parameters: {
record_row_path: "RecordRowPath", # required
},
csv_mapping_parameters: {
record_row_delimiter: "RecordRowDelimiter", # required
record_column_delimiter: "RecordColumnDelimiter", # required
},
},
},
record_encoding: "RecordEncoding",
record_columns: [ # required
{
name: "RecordColumnName", # required
mapping: "RecordColumnMapping",
sql_type: "RecordColumnSqlType", # required
},
],
},
}
When you configure the application input for a SQL-based Kinesis Data Analytics application, you specify the streaming source, the in-application stream name that is created, and the mapping between the two.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_parallelism ⇒ Types::InputParallelism
Describes the number of in-application streams to create.
-
#input_processing_configuration ⇒ Types::InputProcessingConfiguration
The InputProcessingConfiguration for the input.
-
#input_schema ⇒ Types::SourceSchema
Describes the format of the data in the streaming source, and how each data element maps to corresponding columns in the in-application stream that is being created.
-
#kinesis_firehose_input ⇒ Types::KinesisFirehoseInput
If the streaming source is an Amazon Kinesis Data Firehose delivery stream, identifies the delivery stream's ARN.
-
#kinesis_streams_input ⇒ Types::KinesisStreamsInput
If the streaming source is an Amazon Kinesis data stream, identifies the stream's Amazon Resource Name (ARN).
-
#name_prefix ⇒ String
The name prefix to use when creating an in-application stream.
Instance Attribute Details
#input_parallelism ⇒ Types::InputParallelism
Describes the number of in-application streams to create.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |
#input_processing_configuration ⇒ Types::InputProcessingConfiguration
The InputProcessingConfiguration for the input. An input processor transforms records as they are received from the stream, before the application's SQL code executes. Currently, the only input processing configuration available is InputLambdaProcessor.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |
#input_schema ⇒ Types::SourceSchema
Describes the format of the data in the streaming source, and how each data element maps to corresponding columns in the in-application stream that is being created.
Also used to describe the format of the reference data source.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |
#kinesis_firehose_input ⇒ Types::KinesisFirehoseInput
If the streaming source is an Amazon Kinesis Data Firehose delivery stream, identifies the delivery stream's ARN.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |
#kinesis_streams_input ⇒ Types::KinesisStreamsInput
If the streaming source is an Amazon Kinesis data stream, identifies the stream's Amazon Resource Name (ARN).
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |
#name_prefix ⇒ String
The name prefix to use when creating an in-application stream. Suppose that you specify a prefix “`MyInApplicationStream`.” Kinesis Data Analytics then creates one or more (as per the `InputParallelism` count you specified) in-application streams with the names “`MyInApplicationStream_001`,” “`MyInApplicationStream_002`,” and so on.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3493 class Input < Struct.new( :name_prefix, :input_processing_configuration, :kinesis_streams_input, :kinesis_firehose_input, :input_parallelism, :input_schema) SENSITIVE = [] include Aws::Structure end |