Class: Aws::KinesisAnalyticsV2::Types::InputLambdaProcessor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass InputLambdaProcessor data as a hash:

{
  resource_arn: "ResourceARN", # required
}

An object that contains the Amazon Resource Name (ARN) of the Amazon Lambda function that is used to preprocess records in the stream in a SQL-based Kinesis Data Analytics application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The ARN of the Amazon Lambda function that operates on records in the stream.

<note markdown=“1”> To specify an earlier version of the Lambda function than the latest, include the Lambda function version in the Lambda function ARN. For more information about Lambda ARNs, see [Example ARNs: Amazon Lambda]

</note>

[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-lambda

Returns:

  • (String)


3598
3599
3600
3601
3602
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3598

class InputLambdaProcessor < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end