Class: Aws::KinesisAnalyticsV2::Types::InputLambdaProcessorDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::InputLambdaProcessorDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
For a SQL-based Kinesis Data Analytics application, an object that contains the Amazon Resource Name (ARN) of the Amazon Lambda function that is used to preprocess records in the stream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the Amazon Lambda function that is used to preprocess the records in the stream.
-
#role_arn ⇒ String
The ARN of the IAM role that is used to access the Amazon Lambda function.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the Amazon Lambda function that is used to preprocess the records in the stream.
<note markdown=“1”> To specify an earlier version of the Lambda function than the latest, include the Lambda function version in the Lambda function ARN. For more information about Lambda ARNs, see [Example ARNs: Amazon Lambda]
</note>
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-lambda
3637 3638 3639 3640 3641 3642 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3637 class InputLambdaProcessorDescription < Struct.new( :resource_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that is used to access the Amazon Lambda function.
<note markdown=“1”> Provided for backward compatibility. Applications that are created with the current API version have an application-level service execution role rather than a resource-level role.
</note>
3637 3638 3639 3640 3641 3642 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3637 class InputLambdaProcessorDescription < Struct.new( :resource_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |