Class: Aws::KinesisAnalyticsV2::Types::InputParallelismUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::InputParallelismUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass InputParallelismUpdate data as a hash:
{
count_update: 1, # required
}
For a SQL-based Kinesis Data Analytics application, provides updates to the parallelism count.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count_update ⇒ Integer
The number of in-application streams to create for the specified streaming source.
Instance Attribute Details
#count_update ⇒ Integer
The number of in-application streams to create for the specified streaming source.
3719 3720 3721 3722 3723 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3719 class InputParallelismUpdate < Struct.new( :count_update) SENSITIVE = [] include Aws::Structure end |