Class: Aws::KinesisAnalyticsV2::Types::InputProcessingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass InputProcessingConfiguration data as a hash:

{
  input_lambda_processor: { # required
    resource_arn: "ResourceARN", # required
  },
}

For a SQL-based Kinesis Data Analytics application, describes a processor that is used to preprocess the records in the stream before being processed by your application code. Currently, the only input processor available is [Amazon Lambda].

[1]: docs.aws.amazon.com/lambda/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#input_lambda_processorTypes::InputLambdaProcessor

The InputLambdaProcessor that is used to preprocess the records in the stream before being processed by your application code.



3750
3751
3752
3753
3754
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3750

class InputProcessingConfiguration < Struct.new(
  :input_lambda_processor)
  SENSITIVE = []
  include Aws::Structure
end