Class: Aws::KinesisAnalyticsV2::Types::InputSchemaUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass InputSchemaUpdate data as a hash:

{
  record_format_update: {
    record_format_type: "JSON", # required, accepts JSON, CSV
    mapping_parameters: {
      json_mapping_parameters: {
        record_row_path: "RecordRowPath", # required
      },
      csv_mapping_parameters: {
        record_row_delimiter: "RecordRowDelimiter", # required
        record_column_delimiter: "RecordColumnDelimiter", # required
      },
    },
  },
  record_encoding_update: "RecordEncoding",
  record_column_updates: [
    {
      name: "RecordColumnName", # required
      mapping: "RecordColumnMapping",
      sql_type: "RecordColumnSqlType", # required
    },
  ],
}

Describes updates for an SQL-based Kinesis Data Analytics application's input schema.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#record_column_updatesArray<Types::RecordColumn>

A list of `RecordColumn` objects. Each object describes the mapping of the streaming source element to the corresponding column in the in-application stream.

Returns:



3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3847

class InputSchemaUpdate < Struct.new(
  :record_format_update,
  :record_encoding_update,
  :record_column_updates)
  SENSITIVE = []
  include Aws::Structure
end

#record_encoding_updateString

Specifies the encoding of the records in the streaming source; for example, UTF-8.

Returns:

  • (String)


3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3847

class InputSchemaUpdate < Struct.new(
  :record_format_update,
  :record_encoding_update,
  :record_column_updates)
  SENSITIVE = []
  include Aws::Structure
end

#record_format_updateTypes::RecordFormat

Specifies the format of the records on the streaming source.

Returns:



3847
3848
3849
3850
3851
3852
3853
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3847

class InputSchemaUpdate < Struct.new(
  :record_format_update,
  :record_encoding_update,
  :record_column_updates)
  SENSITIVE = []
  include Aws::Structure
end