Class: Aws::KinesisAnalyticsV2::Types::InputUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::InputUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass InputUpdate data as a hash:
{
input_id: "Id", # required
name_prefix_update: "InAppStreamName",
input_processing_configuration_update: {
input_lambda_processor_update: { # required
resource_arn_update: "ResourceARN", # required
},
},
kinesis_streams_input_update: {
resource_arn_update: "ResourceARN", # required
},
kinesis_firehose_input_update: {
resource_arn_update: "ResourceARN", # required
},
input_schema_update: {
record_format_update: {
record_format_type: "JSON", # required, accepts JSON, CSV
mapping_parameters: {
json_mapping_parameters: {
record_row_path: "RecordRowPath", # required
},
csv_mapping_parameters: {
record_row_delimiter: "RecordRowDelimiter", # required
record_column_delimiter: "RecordColumnDelimiter", # required
},
},
},
record_encoding_update: "RecordEncoding",
record_column_updates: [
{
name: "RecordColumnName", # required
mapping: "RecordColumnMapping",
sql_type: "RecordColumnSqlType", # required
},
],
},
input_parallelism_update: {
count_update: 1, # required
},
}
For a SQL-based Kinesis Data Analytics application, describes updates to a specific input configuration (identified by the `InputId` of an application).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_id ⇒ String
The input ID of the application input to be updated.
-
#input_parallelism_update ⇒ Types::InputParallelismUpdate
Describes the parallelism updates (the number of in-application streams Kinesis Data Analytics creates for the specific streaming source).
-
#input_processing_configuration_update ⇒ Types::InputProcessingConfigurationUpdate
Describes updates to an InputProcessingConfiguration.
-
#input_schema_update ⇒ Types::InputSchemaUpdate
Describes the data format on the streaming source, and how record elements on the streaming source map to columns of the in-application stream that is created.
-
#kinesis_firehose_input_update ⇒ Types::KinesisFirehoseInputUpdate
If a Kinesis Data Firehose delivery stream is the streaming source to be updated, provides an updated stream ARN.
-
#kinesis_streams_input_update ⇒ Types::KinesisStreamsInputUpdate
If a Kinesis data stream is the streaming source to be updated, provides an updated stream Amazon Resource Name (ARN).
-
#name_prefix_update ⇒ String
The name prefix for in-application streams that Kinesis Data Analytics creates for the specific streaming source.
Instance Attribute Details
#input_id ⇒ String
The input ID of the application input to be updated.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#input_parallelism_update ⇒ Types::InputParallelismUpdate
Describes the parallelism updates (the number of in-application streams Kinesis Data Analytics creates for the specific streaming source).
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#input_processing_configuration_update ⇒ Types::InputProcessingConfigurationUpdate
Describes updates to an InputProcessingConfiguration.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#input_schema_update ⇒ Types::InputSchemaUpdate
Describes the data format on the streaming source, and how record elements on the streaming source map to columns of the in-application stream that is created.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#kinesis_firehose_input_update ⇒ Types::KinesisFirehoseInputUpdate
If a Kinesis Data Firehose delivery stream is the streaming source to be updated, provides an updated stream ARN.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#kinesis_streams_input_update ⇒ Types::KinesisStreamsInputUpdate
If a Kinesis data stream is the streaming source to be updated, provides an updated stream Amazon Resource Name (ARN).
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |
#name_prefix_update ⇒ String
The name prefix for in-application streams that Kinesis Data Analytics creates for the specific streaming source.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3972 class InputUpdate < Struct.new( :input_id, :name_prefix_update, :input_processing_configuration_update, :kinesis_streams_input_update, :kinesis_firehose_input_update, :input_schema_update, :input_parallelism_update) SENSITIVE = [] include Aws::Structure end |