Class: Aws::KinesisAnalyticsV2::Types::Output
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::Output
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass Output data as a hash:
{
name: "InAppStreamName", # required
kinesis_streams_output: {
resource_arn: "ResourceARN", # required
},
kinesis_firehose_output: {
resource_arn: "ResourceARN", # required
},
lambda_output: {
resource_arn: "ResourceARN", # required
},
destination_schema: { # required
record_format_type: "JSON", # required, accepts JSON, CSV
},
}
Describes a SQL-based Kinesis Data Analytics application's output configuration, in which you identify an in-application stream and a destination where you want the in-application stream data to be written. The destination can be a Kinesis data stream or a Kinesis Data Firehose delivery stream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_schema ⇒ Types::DestinationSchema
Describes the data format when records are written to the destination.
-
#kinesis_firehose_output ⇒ Types::KinesisFirehoseOutput
Identifies a Kinesis Data Firehose delivery stream as the destination.
-
#kinesis_streams_output ⇒ Types::KinesisStreamsOutput
Identifies a Kinesis data stream as the destination.
-
#lambda_output ⇒ Types::LambdaOutput
Identifies an Amazon Lambda function as the destination.
-
#name ⇒ String
The name of the in-application stream.
Instance Attribute Details
#destination_schema ⇒ Types::DestinationSchema
Describes the data format when records are written to the destination.
4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4902 class Output < Struct.new( :name, :kinesis_streams_output, :kinesis_firehose_output, :lambda_output, :destination_schema) SENSITIVE = [] include Aws::Structure end |
#kinesis_firehose_output ⇒ Types::KinesisFirehoseOutput
Identifies a Kinesis Data Firehose delivery stream as the destination.
4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4902 class Output < Struct.new( :name, :kinesis_streams_output, :kinesis_firehose_output, :lambda_output, :destination_schema) SENSITIVE = [] include Aws::Structure end |
#kinesis_streams_output ⇒ Types::KinesisStreamsOutput
Identifies a Kinesis data stream as the destination.
4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4902 class Output < Struct.new( :name, :kinesis_streams_output, :kinesis_firehose_output, :lambda_output, :destination_schema) SENSITIVE = [] include Aws::Structure end |
#lambda_output ⇒ Types::LambdaOutput
Identifies an Amazon Lambda function as the destination.
4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4902 class Output < Struct.new( :name, :kinesis_streams_output, :kinesis_firehose_output, :lambda_output, :destination_schema) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the in-application stream.
4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4902 class Output < Struct.new( :name, :kinesis_streams_output, :kinesis_firehose_output, :lambda_output, :destination_schema) SENSITIVE = [] include Aws::Structure end |