Class: Aws::KinesisAnalyticsV2::Types::ParallelismConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ParallelismConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Describes parameters for how a Flink-based Kinesis Data Analytics application executes multiple tasks simultaneously. For more information about parallelism, see [Parallel Execution] in the [Apache Flink Documentation].
[1]: ci.apache.org/projects/flink/flink-docs-release-1.8/dev/parallel.html [2]: ci.apache.org/projects/flink/flink-docs-release-1.8/
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_enabled ⇒ Boolean
Describes whether the Kinesis Data Analytics service can increase the parallelism of the application in response to increased throughput.
-
#configuration_type ⇒ String
Describes whether the application uses the default parallelism for the Kinesis Data Analytics service.
-
#parallelism ⇒ Integer
Describes the initial number of parallel tasks that a Flink-based Kinesis Data Analytics application can perform.
-
#parallelism_per_kpu ⇒ Integer
Describes the number of parallel tasks that a Flink-based Kinesis Data Analytics application can perform per Kinesis Processing Unit (KPU) used by the application.
Instance Attribute Details
#auto_scaling_enabled ⇒ Boolean
Describes whether the Kinesis Data Analytics service can increase the parallelism of the application in response to increased throughput.
3604 3605 3606 3607 3608 3609 3610 3611 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3604 class ParallelismConfiguration < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#configuration_type ⇒ String
Describes whether the application uses the default parallelism for the Kinesis Data Analytics service. You must set this property to `CUSTOM` in order to change your application's `AutoScalingEnabled`, `Parallelism`, or `ParallelismPerKPU` properties.
3604 3605 3606 3607 3608 3609 3610 3611 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3604 class ParallelismConfiguration < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#parallelism ⇒ Integer
Describes the initial number of parallel tasks that a Flink-based Kinesis Data Analytics application can perform. If `AutoScalingEnabled` is set to True, Kinesis Data Analytics increases the `CurrentParallelism` value in response to application load. The service can increase the `CurrentParallelism` value up to the maximum parallelism, which is `ParalellismPerKPU` times the maximum KPUs for the application. The maximum KPUs for an application is 32 by default, and can be increased by requesting a limit increase. If application load is reduced, the service can reduce the `CurrentParallelism` value down to the `Parallelism` setting.
3604 3605 3606 3607 3608 3609 3610 3611 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3604 class ParallelismConfiguration < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#parallelism_per_kpu ⇒ Integer
Describes the number of parallel tasks that a Flink-based Kinesis Data Analytics application can perform per Kinesis Processing Unit (KPU) used by the application. For more information about KPUs, see [Amazon Kinesis Data Analytics Pricing].
3604 3605 3606 3607 3608 3609 3610 3611 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3604 class ParallelismConfiguration < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |