Class: Aws::KinesisAnalyticsV2::Types::ParallelismConfigurationDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ParallelismConfigurationDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Describes parameters for how a Managed Service for Apache Flink application executes multiple tasks simultaneously.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_enabled ⇒ Boolean
Describes whether the Managed Service for Apache Flink service can increase the parallelism of the application in response to increased throughput.
-
#configuration_type ⇒ String
Describes whether the application uses the default parallelism for the Managed Service for Apache Flink service.
-
#current_parallelism ⇒ Integer
Describes the current number of parallel tasks that a Managed Service for Apache Flink application can perform.
-
#parallelism ⇒ Integer
Describes the initial number of parallel tasks that a Managed Service for Apache Flink application can perform.
-
#parallelism_per_kpu ⇒ Integer
Describes the number of parallel tasks that a Managed Service for Apache Flink application can perform per Kinesis Processing Unit (KPU) used by the application.
Instance Attribute Details
#auto_scaling_enabled ⇒ Boolean
Describes whether the Managed Service for Apache Flink service can increase the parallelism of the application in response to increased throughput.
3665 3666 3667 3668 3669 3670 3671 3672 3673 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3665 class ParallelismConfigurationDescription < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :current_parallelism, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#configuration_type ⇒ String
Describes whether the application uses the default parallelism for the Managed Service for Apache Flink service.
3665 3666 3667 3668 3669 3670 3671 3672 3673 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3665 class ParallelismConfigurationDescription < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :current_parallelism, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#current_parallelism ⇒ Integer
Describes the current number of parallel tasks that a Managed Service for Apache Flink application can perform. If ‘AutoScalingEnabled` is set to True, Managed Service for Apache Flink can increase this value in response to application load. The service can increase this value up to the maximum parallelism, which is `ParalellismPerKPU` times the maximum KPUs for the application. The maximum KPUs for an application is 32 by default, and can be increased by requesting a limit increase. If application load is reduced, the service can reduce the `CurrentParallelism` value down to the `Parallelism` setting.
3665 3666 3667 3668 3669 3670 3671 3672 3673 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3665 class ParallelismConfigurationDescription < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :current_parallelism, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#parallelism ⇒ Integer
Describes the initial number of parallel tasks that a Managed Service for Apache Flink application can perform. If ‘AutoScalingEnabled` is set to True, then Managed Service for Apache Flink can increase the `CurrentParallelism` value in response to application load. The service can increase `CurrentParallelism` up to the maximum parallelism, which is `ParalellismPerKPU` times the maximum KPUs for the application. The maximum KPUs for an application is 32 by default, and can be increased by requesting a limit increase. If application load is reduced, the service can reduce the `CurrentParallelism` value down to the `Parallelism` setting.
3665 3666 3667 3668 3669 3670 3671 3672 3673 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3665 class ParallelismConfigurationDescription < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :current_parallelism, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |
#parallelism_per_kpu ⇒ Integer
Describes the number of parallel tasks that a Managed Service for Apache Flink application can perform per Kinesis Processing Unit (KPU) used by the application.
3665 3666 3667 3668 3669 3670 3671 3672 3673 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3665 class ParallelismConfigurationDescription < Struct.new( :configuration_type, :parallelism, :parallelism_per_kpu, :current_parallelism, :auto_scaling_enabled) SENSITIVE = [] include Aws::Structure end |