Class: Aws::KinesisAnalyticsV2::Types::ParallelismConfigurationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Describes updates to parameters for how an application executes multiple tasks simultaneously.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_enabled_updateBoolean

Describes updates to whether the Kinesis Data Analytics service can increase the parallelism of a Flink-based Kinesis Data Analytics application in response to increased throughput.

Returns:

  • (Boolean)


3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3708

class ParallelismConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :parallelism_update,
  :parallelism_per_kpu_update,
  :auto_scaling_enabled_update)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_type_updateString

Describes updates to whether the application uses the default parallelism for the Kinesis Data Analytics service, or if a custom parallelism is used. You must set this property to `CUSTOM` in order to change your application's `AutoScalingEnabled`, `Parallelism`, or `ParallelismPerKPU` properties.

Returns:

  • (String)


3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3708

class ParallelismConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :parallelism_update,
  :parallelism_per_kpu_update,
  :auto_scaling_enabled_update)
  SENSITIVE = []
  include Aws::Structure
end

#parallelism_per_kpu_updateInteger

Describes updates to the number of parallel tasks an application can perform per Kinesis Processing Unit (KPU) used by the application.

Returns:

  • (Integer)


3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3708

class ParallelismConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :parallelism_update,
  :parallelism_per_kpu_update,
  :auto_scaling_enabled_update)
  SENSITIVE = []
  include Aws::Structure
end

#parallelism_updateInteger

Describes updates to the initial number of parallel tasks an application can perform. If `AutoScalingEnabled` is set to True, then Kinesis Data Analytics can increase the `CurrentParallelism` value in response to application load. The service can increase `CurrentParallelism` up to the maximum parallelism, which is `ParalellismPerKPU` times the maximum KPUs for the application. The maximum KPUs for an application is 32 by default, and can be increased by requesting a limit increase. If application load is reduced, the service will reduce `CurrentParallelism` down to the `Parallelism` setting.

Returns:

  • (Integer)


3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3708

class ParallelismConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :parallelism_update,
  :parallelism_per_kpu_update,
  :auto_scaling_enabled_update)
  SENSITIVE = []
  include Aws::Structure
end