Class: Aws::KinesisAnalyticsV2::Types::PropertyGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::PropertyGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass PropertyGroup data as a hash:
{
property_group_id: "Id", # required
property_map: { # required
"PropertyKey" => "PropertyValue",
},
}
Property key-value pairs passed into an application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#property_group_id ⇒ String
Describes the key of an application execution property key-value pair.
-
#property_map ⇒ Hash<String,String>
Describes the value of an application execution property key-value pair.
Instance Attribute Details
#property_group_id ⇒ String
Describes the key of an application execution property key-value pair.
5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5232 class PropertyGroup < Struct.new( :property_group_id, :property_map) SENSITIVE = [] include Aws::Structure end |
#property_map ⇒ Hash<String,String>
Describes the value of an application execution property key-value pair.
5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5232 class PropertyGroup < Struct.new( :property_group_id, :property_map) SENSITIVE = [] include Aws::Structure end |