Class: Aws::KinesisAnalyticsV2::Types::ReferenceDataSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

For a SQL-based Kinesis Data Analytics application, describes the reference data source by providing the source information (Amazon S3 bucket name and object key name), the resulting in-application table name that is created, and the necessary schema to map the data elements in the Amazon S3 object to the in-application table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reference_schemaTypes::SourceSchema

Describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.

Returns:



4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4210

class ReferenceDataSource < Struct.new(
  :table_name,
  :s3_reference_data_source,
  :reference_schema)
  SENSITIVE = []
  include Aws::Structure
end

#s3_reference_data_sourceTypes::S3ReferenceDataSource

Identifies the S3 bucket and object that contains the reference data. A SQL-based Kinesis Data Analytics application loads reference data only once. If the data changes, you call the UpdateApplication operation to trigger reloading of data into your application.

Returns:



4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4210

class ReferenceDataSource < Struct.new(
  :table_name,
  :s3_reference_data_source,
  :reference_schema)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the in-application table to create.

Returns:



4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4210

class ReferenceDataSource < Struct.new(
  :table_name,
  :s3_reference_data_source,
  :reference_schema)
  SENSITIVE = []
  include Aws::Structure
end