Class: Aws::KinesisAnalyticsV2::Types::S3ContentLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::S3ContentLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) for the S3 bucket containing the application code.
-
#file_key ⇒ String
The file key for the object containing the application code.
-
#object_version ⇒ String
The version of the object containing the application code.
Instance Attribute Details
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) for the S3 bucket containing the application code.
4176 4177 4178 4179 4180 4181 4182 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4176 class S3ContentLocation < Struct.new( :bucket_arn, :file_key, :object_version) SENSITIVE = [] include Aws::Structure end |
#file_key ⇒ String
The file key for the object containing the application code.
4176 4177 4178 4179 4180 4181 4182 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4176 class S3ContentLocation < Struct.new( :bucket_arn, :file_key, :object_version) SENSITIVE = [] include Aws::Structure end |
#object_version ⇒ String
The version of the object containing the application code.
4176 4177 4178 4179 4180 4181 4182 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4176 class S3ContentLocation < Struct.new( :bucket_arn, :file_key, :object_version) SENSITIVE = [] include Aws::Structure end |