Class: Aws::KinesisAnalyticsV2::Types::S3ContentLocationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass S3ContentLocationUpdate data as a hash:

{
  bucket_arn_update: "BucketARN",
  file_key_update: "FileKey",
  object_version_update: "ObjectVersion",
}

Describes an update for the Amazon S3 code content location for an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_arn_updateString

The new Amazon Resource Name (ARN) for the S3 bucket containing the application code.

Returns:

  • (String)


5879
5880
5881
5882
5883
5884
5885
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5879

class S3ContentLocationUpdate < Struct.new(
  :bucket_arn_update,
  :file_key_update,
  :object_version_update)
  SENSITIVE = []
  include Aws::Structure
end

#file_key_updateString

The new file key for the object containing the application code.

Returns:

  • (String)


5879
5880
5881
5882
5883
5884
5885
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5879

class S3ContentLocationUpdate < Struct.new(
  :bucket_arn_update,
  :file_key_update,
  :object_version_update)
  SENSITIVE = []
  include Aws::Structure
end

#object_version_updateString

The new version of the object containing the application code.

Returns:

  • (String)


5879
5880
5881
5882
5883
5884
5885
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5879

class S3ContentLocationUpdate < Struct.new(
  :bucket_arn_update,
  :file_key_update,
  :object_version_update)
  SENSITIVE = []
  include Aws::Structure
end