Class: Aws::KinesisAnalyticsV2::Types::ZeppelinApplicationConfigurationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ZeppelinApplicationConfigurationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass ZeppelinApplicationConfigurationUpdate data as a hash:
{
monitoring_configuration_update: {
log_level_update: "INFO", # required, accepts INFO, WARN, ERROR, DEBUG
},
catalog_configuration_update: {
glue_data_catalog_configuration_update: { # required
database_arn_update: "DatabaseARN", # required
},
},
deploy_as_application_configuration_update: {
s3_content_location_update: {
bucket_arn_update: "BucketARN",
base_path_update: "BasePath",
},
},
custom_artifacts_configuration_update: [
{
artifact_type: "UDF", # required, accepts UDF, DEPENDENCY_JAR
s3_content_location: {
bucket_arn: "BucketARN", # required
file_key: "FileKey", # required
object_version: "ObjectVersion",
},
maven_reference: {
group_id: "MavenGroupId", # required
artifact_id: "MavenArtifactId", # required
version: "MavenVersion", # required
},
},
],
}
Updates to the configuration of Kinesis Data Analytics Studio notebook.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_configuration_update ⇒ Types::CatalogConfigurationUpdate
Updates to the configuration of the Amazon Glue Data Catalog that is associated with the Kinesis Data Analytics Studio notebook.
-
#custom_artifacts_configuration_update ⇒ Array<Types::CustomArtifactConfiguration>
Updates to the customer artifacts.
-
#deploy_as_application_configuration_update ⇒ Types::DeployAsApplicationConfigurationUpdate
Updates to the configuration information required to deploy an Amazon Data Analytics Studio notebook as an application with durable state.
-
#monitoring_configuration_update ⇒ Types::ZeppelinMonitoringConfigurationUpdate
Updates to the monitoring configuration of a Kinesis Data Analytics Studio notebook.
Instance Attribute Details
#catalog_configuration_update ⇒ Types::CatalogConfigurationUpdate
Updates to the configuration of the Amazon Glue Data Catalog that is associated with the Kinesis Data Analytics Studio notebook.
7224 7225 7226 7227 7228 7229 7230 7231 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 7224 class ZeppelinApplicationConfigurationUpdate < Struct.new( :monitoring_configuration_update, :catalog_configuration_update, :deploy_as_application_configuration_update, :custom_artifacts_configuration_update) SENSITIVE = [] include Aws::Structure end |
#custom_artifacts_configuration_update ⇒ Array<Types::CustomArtifactConfiguration>
Updates to the customer artifacts. Custom artifacts are dependency JAR files and user-defined functions (UDF).
7224 7225 7226 7227 7228 7229 7230 7231 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 7224 class ZeppelinApplicationConfigurationUpdate < Struct.new( :monitoring_configuration_update, :catalog_configuration_update, :deploy_as_application_configuration_update, :custom_artifacts_configuration_update) SENSITIVE = [] include Aws::Structure end |
#deploy_as_application_configuration_update ⇒ Types::DeployAsApplicationConfigurationUpdate
Updates to the configuration information required to deploy an Amazon Data Analytics Studio notebook as an application with durable state.
7224 7225 7226 7227 7228 7229 7230 7231 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 7224 class ZeppelinApplicationConfigurationUpdate < Struct.new( :monitoring_configuration_update, :catalog_configuration_update, :deploy_as_application_configuration_update, :custom_artifacts_configuration_update) SENSITIVE = [] include Aws::Structure end |
#monitoring_configuration_update ⇒ Types::ZeppelinMonitoringConfigurationUpdate
Updates to the monitoring configuration of a Kinesis Data Analytics Studio notebook.
7224 7225 7226 7227 7228 7229 7230 7231 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 7224 class ZeppelinApplicationConfigurationUpdate < Struct.new( :monitoring_configuration_update, :catalog_configuration_update, :deploy_as_application_configuration_update, :custom_artifacts_configuration_update) SENSITIVE = [] include Aws::Structure end |