Class: Aws::KinesisAnalyticsV2::Types::ZeppelinMonitoringConfigurationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::ZeppelinMonitoringConfigurationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass ZeppelinMonitoringConfigurationUpdate data as a hash:
{
log_level_update: "INFO", # required, accepts INFO, WARN, ERROR, DEBUG
}
Updates to the monitoring configuration for Apache Zeppelin within a Kinesis Data Analytics Studio notebook.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_level_update ⇒ String
Updates to the logging level for Apache Zeppelin within a Kinesis Data Analytics Studio notebook.
Instance Attribute Details
#log_level_update ⇒ String
Updates to the logging level for Apache Zeppelin within a Kinesis Data Analytics Studio notebook.
7290 7291 7292 7293 7294 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 7290 class ZeppelinMonitoringConfigurationUpdate < Struct.new( :log_level_update) SENSITIVE = [] include Aws::Structure end |