Class: Aws::KinesisAnalyticsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KinesisAnalyticsV2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/client.rb
Overview
An API client for KinesisAnalyticsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KinesisAnalyticsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_application_cloud_watch_logging_option(params = {}) ⇒ Types::AddApplicationCloudWatchLoggingOptionResponse
Adds an Amazon CloudWatch log stream to monitor application configuration errors.
-
#add_application_input(params = {}) ⇒ Types::AddApplicationInputResponse
Adds a streaming source to your SQL-based Kinesis Data Analytics application.
-
#add_application_input_processing_configuration(params = {}) ⇒ Types::AddApplicationInputProcessingConfigurationResponse
Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application.
-
#add_application_output(params = {}) ⇒ Types::AddApplicationOutputResponse
Adds an external destination to your SQL-based Kinesis Data Analytics application.
-
#add_application_reference_data_source(params = {}) ⇒ Types::AddApplicationReferenceDataSourceResponse
Adds a reference data source to an existing SQL-based Kinesis Data Analytics application.
-
#add_application_vpc_configuration(params = {}) ⇒ Types::AddApplicationVpcConfigurationResponse
Adds a Virtual Private Cloud (VPC) configuration to the application.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a Managed Service for Apache Flink application.
-
#create_application_presigned_url(params = {}) ⇒ Types::CreateApplicationPresignedUrlResponse
Creates and returns a URL that you can use to connect to an application’s extension.
-
#create_application_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the application’s state data.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
-
#delete_application_cloud_watch_logging_option(params = {}) ⇒ Types::DeleteApplicationCloudWatchLoggingOptionResponse
Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application.
-
#delete_application_input_processing_configuration(params = {}) ⇒ Types::DeleteApplicationInputProcessingConfigurationResponse
Deletes an InputProcessingConfiguration from an input.
-
#delete_application_output(params = {}) ⇒ Types::DeleteApplicationOutputResponse
Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application’s configuration.
-
#delete_application_reference_data_source(params = {}) ⇒ Types::DeleteApplicationReferenceDataSourceResponse
Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application’s configuration.
-
#delete_application_snapshot(params = {}) ⇒ Struct
Deletes a snapshot of application state.
-
#delete_application_vpc_configuration(params = {}) ⇒ Types::DeleteApplicationVpcConfigurationResponse
Removes a VPC configuration from a Managed Service for Apache Flink application.
-
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Returns information about a specific Managed Service for Apache Flink application.
-
#describe_application_operation(params = {}) ⇒ Types::DescribeApplicationOperationResponse
Returns information about a specific operation performed on a Managed Service for Apache Flink application.
-
#describe_application_snapshot(params = {}) ⇒ Types::DescribeApplicationSnapshotResponse
Returns information about a snapshot of application state data.
-
#describe_application_version(params = {}) ⇒ Types::DescribeApplicationVersionResponse
Provides a detailed description of a specified version of the application.
-
#discover_input_schema(params = {}) ⇒ Types::DiscoverInputSchemaResponse
Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object.
-
#list_application_operations(params = {}) ⇒ Types::ListApplicationOperationsResponse
Lists information about operations performed on a Managed Service for Apache Flink application.
-
#list_application_snapshots(params = {}) ⇒ Types::ListApplicationSnapshotsResponse
Lists information about the current application snapshots.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists all the versions for the specified application, including versions that were rolled back.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a list of Managed Service for Apache Flink applications in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of key-value tags assigned to the application.
-
#rollback_application(params = {}) ⇒ Types::RollbackApplicationResponse
Reverts the application to the previous running version.
-
#start_application(params = {}) ⇒ Types::StartApplicationResponse
Starts the specified Managed Service for Apache Flink application.
-
#stop_application(params = {}) ⇒ Types::StopApplicationResponse
Stops the application from processing data.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more key-value tags to a Managed Service for Apache Flink application.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a Managed Service for Apache Flink application.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing Managed Service for Apache Flink application.
-
#update_application_maintenance_configuration(params = {}) ⇒ Types::UpdateApplicationMaintenanceConfigurationResponse
Updates the maintenance configuration of the Managed Service for Apache Flink application.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
429 430 431 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 429 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3241 3242 3243 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3241 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3244 3245 3246 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3244 def errors_module Errors end |
Instance Method Details
#add_application_cloud_watch_logging_option(params = {}) ⇒ Types::AddApplicationCloudWatchLoggingOptionResponse
Adds an Amazon CloudWatch log stream to monitor application configuration errors.
491 492 493 494 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 491 def add_application_cloud_watch_logging_option(params = {}, = {}) req = build_request(:add_application_cloud_watch_logging_option, params) req.send_request() end |
#add_application_input(params = {}) ⇒ Types::AddApplicationInputResponse
Adds a streaming source to your SQL-based Kinesis Data Analytics application.
You can add a streaming source when you create an application, or you can use this operation to add a streaming source after you create an application. For more information, see CreateApplication.
Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.
603 604 605 606 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 603 def add_application_input(params = {}, = {}) req = build_request(:add_application_input, params) req.send_request() end |
#add_application_input_processing_configuration(params = {}) ⇒ Types::AddApplicationInputProcessingConfigurationResponse
Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application. An input processor pre-processes records on the input stream before the application’s SQL code executes. Currently, the only input processor available is [Amazon Lambda].
668 669 670 671 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 668 def add_application_input_processing_configuration(params = {}, = {}) req = build_request(:add_application_input_processing_configuration, params) req.send_request() end |
#add_application_output(params = {}) ⇒ Types::AddApplicationOutputResponse
Adds an external destination to your SQL-based Kinesis Data Analytics application.
If you want Kinesis Data Analytics to deliver data from an in-application stream within your application to an external destination (such as an Kinesis data stream, a Kinesis Data Firehose delivery stream, or an Amazon Lambda function), you add the relevant configuration to your application using this operation. You can configure one or more outputs for your application. Each output configuration maps an in-application stream and an external destination.
You can use one of the output configurations to deliver data from your in-application error stream to an external destination so that you can analyze the errors.
Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.
758 759 760 761 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 758 def add_application_output(params = {}, = {}) req = build_request(:add_application_output, params) req.send_request() end |
#add_application_reference_data_source(params = {}) ⇒ Types::AddApplicationReferenceDataSourceResponse
Adds a reference data source to an existing SQL-based Kinesis Data Analytics application.
Kinesis Data Analytics reads reference data (that is, an Amazon S3 object) and creates an in-application table within your application. In the request, you provide the source (S3 bucket name and object key name), name of the in-application table to create, and the necessary mapping information that describes how data in an Amazon S3 object maps to columns in the resulting in-application table.
854 855 856 857 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 854 def add_application_reference_data_source(params = {}, = {}) req = build_request(:add_application_reference_data_source, params) req.send_request() end |
#add_application_vpc_configuration(params = {}) ⇒ Types::AddApplicationVpcConfigurationResponse
Adds a Virtual Private Cloud (VPC) configuration to the application. Applications can use VPCs to store and access resources securely.
Note the following about VPC configurations for Managed Service for Apache Flink applications:
-
VPC configurations are not supported for SQL applications.
-
When a VPC is added to a Managed Service for Apache Flink application, the application can no longer be accessed from the Internet directly. To enable Internet access to the application, add an Internet gateway to your VPC.
930 931 932 933 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 930 def add_application_vpc_configuration(params = {}, = {}) req = build_request(:add_application_vpc_configuration, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3219 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-kinesisanalyticsv2' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a Managed Service for Apache Flink application. For information about creating a Managed Service for Apache Flink application, see [Creating an Application].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html
1305 1306 1307 1308 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1305 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_application_presigned_url(params = {}) ⇒ Types::CreateApplicationPresignedUrlResponse
Creates and returns a URL that you can use to connect to an application’s extension.
The IAM role or user used to call this API defines the permissions to access the extension. After the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request that attempts to connect to the extension.
You control the amount of time that the URL will be valid using the ‘SessionExpirationDurationInSeconds` parameter. If you do not provide this parameter, the returned URL is valid for twelve hours.
<note markdown=“1”> The URL that you get from a call to CreateApplicationPresignedUrl must be used within 3 minutes to be valid. If you first try to use the URL after the 3-minute limit expires, the service returns an HTTP 403 Forbidden error.
</note>
1360 1361 1362 1363 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1360 def create_application_presigned_url(params = {}, = {}) req = build_request(:create_application_presigned_url, params) req.send_request() end |
#create_application_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the application’s state data.
1386 1387 1388 1389 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1386 def create_application_snapshot(params = {}, = {}) req = build_request(:create_application_snapshot, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the specified application. Managed Service for Apache Flink halts application execution and deletes the application.
1413 1414 1415 1416 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1413 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_application_cloud_watch_logging_option(params = {}) ⇒ Types::DeleteApplicationCloudWatchLoggingOptionResponse
Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application.
1474 1475 1476 1477 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1474 def delete_application_cloud_watch_logging_option(params = {}, = {}) req = build_request(:delete_application_cloud_watch_logging_option, params) req.send_request() end |
#delete_application_input_processing_configuration(params = {}) ⇒ Types::DeleteApplicationInputProcessingConfigurationResponse
Deletes an InputProcessingConfiguration from an input.
1517 1518 1519 1520 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1517 def delete_application_input_processing_configuration(params = {}, = {}) req = build_request(:delete_application_input_processing_configuration, params) req.send_request() end |
#delete_application_output(params = {}) ⇒ Types::DeleteApplicationOutputResponse
Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application’s configuration. Kinesis Data Analytics will no longer write data from the corresponding in-application stream to the external output destination.
1566 1567 1568 1569 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1566 def delete_application_output(params = {}, = {}) req = build_request(:delete_application_output, params) req.send_request() end |
#delete_application_reference_data_source(params = {}) ⇒ Types::DeleteApplicationReferenceDataSourceResponse
Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application’s configuration.
If the application is running, Kinesis Data Analytics immediately removes the in-application table that you created using the AddApplicationReferenceDataSource operation.
1616 1617 1618 1619 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1616 def delete_application_reference_data_source(params = {}, = {}) req = build_request(:delete_application_reference_data_source, params) req.send_request() end |
#delete_application_snapshot(params = {}) ⇒ Struct
Deletes a snapshot of application state.
1647 1648 1649 1650 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1647 def delete_application_snapshot(params = {}, = {}) req = build_request(:delete_application_snapshot, params) req.send_request() end |
#delete_application_vpc_configuration(params = {}) ⇒ Types::DeleteApplicationVpcConfigurationResponse
Removes a VPC configuration from a Managed Service for Apache Flink application.
1701 1702 1703 1704 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1701 def delete_application_vpc_configuration(params = {}, = {}) req = build_request(:delete_application_vpc_configuration, params) req.send_request() end |
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Returns information about a specific Managed Service for Apache Flink application.
If you want to retrieve a list of all applications in your account, use the ListApplications operation.
1853 1854 1855 1856 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1853 def describe_application(params = {}, = {}) req = build_request(:describe_application, params) req.send_request() end |
#describe_application_operation(params = {}) ⇒ Types::DescribeApplicationOperationResponse
Returns information about a specific operation performed on a Managed Service for Apache Flink application
1893 1894 1895 1896 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1893 def describe_application_operation(params = {}, = {}) req = build_request(:describe_application_operation, params) req.send_request() end |
#describe_application_snapshot(params = {}) ⇒ Types::DescribeApplicationSnapshotResponse
Returns information about a snapshot of application state data.
1930 1931 1932 1933 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1930 def describe_application_snapshot(params = {}, = {}) req = build_request(:describe_application_snapshot, params) req.send_request() end |
#describe_application_version(params = {}) ⇒ Types::DescribeApplicationVersionResponse
Provides a detailed description of a specified version of the application. To see a list of all the versions of an application, invoke the ListApplicationVersions operation.
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
2085 2086 2087 2088 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2085 def describe_application_version(params = {}, = {}) req = build_request(:describe_application_version, params) req.send_request() end |
#discover_input_schema(params = {}) ⇒ Types::DiscoverInputSchemaResponse
Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object. In the response, the operation returns the inferred schema and also the sample records that the operation used to infer the schema.
You can use the inferred schema when configuring a streaming source for your application. When you create an application using the Kinesis Data Analytics console, the console uses this operation to infer a schema and show it in the console user interface.
2168 2169 2170 2171 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2168 def discover_input_schema(params = {}, = {}) req = build_request(:discover_input_schema, params) req.send_request() end |
#list_application_operations(params = {}) ⇒ Types::ListApplicationOperationsResponse
Lists information about operations performed on a Managed Service for Apache Flink application
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2223 2224 2225 2226 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2223 def list_application_operations(params = {}, = {}) req = build_request(:list_application_operations, params) req.send_request() end |
#list_application_snapshots(params = {}) ⇒ Types::ListApplicationSnapshotsResponse
Lists information about the current application snapshots.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2271 2272 2273 2274 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2271 def list_application_snapshots(params = {}, = {}) req = build_request(:list_application_snapshots, params) req.send_request() end |
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists all the versions for the specified application, including versions that were rolled back. The response also includes a summary of the configuration associated with each version.
To get the complete description of a specific application version, invoke the DescribeApplicationVersion operation.
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2330 2331 2332 2333 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2330 def list_application_versions(params = {}, = {}) req = build_request(:list_application_versions, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a list of Managed Service for Apache Flink applications in your account. For each application, the response includes the application name, Amazon Resource Name (ARN), and status.
If you want detailed information about a specific application, use DescribeApplication.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2384 2385 2386 2387 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2384 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of key-value tags assigned to the application. For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2419 2420 2421 2422 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2419 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#rollback_application(params = {}) ⇒ Types::RollbackApplicationResponse
Reverts the application to the previous running version. You can roll back an application if you suspect it is stuck in a transient status or in the running status.
You can roll back an application only if it is in the ‘UPDATING`, `AUTOSCALING`, or `RUNNING` statuses.
When you rollback an application, it loads state data from the last successful snapshot. If the application has no snapshots, Managed Service for Apache Flink rejects the rollback request.
2578 2579 2580 2581 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2578 def rollback_application(params = {}, = {}) req = build_request(:rollback_application, params) req.send_request() end |
#start_application(params = {}) ⇒ Types::StartApplicationResponse
Starts the specified Managed Service for Apache Flink application. After creating an application, you must exclusively call this operation to start your application.
2629 2630 2631 2632 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2629 def start_application(params = {}, = {}) req = build_request(:start_application, params) req.send_request() end |
#stop_application(params = {}) ⇒ Types::StopApplicationResponse
Stops the application from processing data. You can stop an application only if it is in the running status, unless you set the ‘Force` parameter to `true`.
You can use the DescribeApplication operation to find the application status.
Managed Service for Apache Flink takes a snapshot when the application is stopped, unless ‘Force` is set to `true`.
2685 2686 2687 2688 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2685 def stop_application(params = {}, = {}) req = build_request(:stop_application, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more key-value tags to a Managed Service for Apache Flink application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is
-
For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2723 2724 2725 2726 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2723 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a Managed Service for Apache Flink application. For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2755 2756 2757 2758 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2755 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing Managed Service for Apache Flink application. Using this operation, you can update application code, input configuration, and output configuration.
Managed Service for Apache Flink updates the ‘ApplicationVersionId` each time you update your application.
3145 3146 3147 3148 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3145 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_application_maintenance_configuration(params = {}) ⇒ Types::UpdateApplicationMaintenanceConfigurationResponse
Updates the maintenance configuration of the Managed Service for Apache Flink application.
You can invoke this operation on an application that is in one of the two following states: ‘READY` or `RUNNING`. If you invoke it when the application is in a state other than these two states, it throws a `ResourceInUseException`. The service makes use of the updated configuration the next time it schedules maintenance for the application. If you invoke this operation after the service schedules maintenance, the service will apply the configuration update the next time it schedules maintenance for the application. This means that you might not see the maintenance configuration update applied to the maintenance process that follows a successful invocation of this operation, but to the following maintenance process instead.
To see the current maintenance configuration of your application, invoke the DescribeApplication operation.
For information about application maintenance, see [Managed Service for Apache Flink for Apache Flink Maintenance].
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/maintenance.html
3210 3211 3212 3213 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3210 def update_application_maintenance_configuration(params = {}, = {}) req = build_request(:update_application_maintenance_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3234 3235 3236 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3234 def waiter_names [] end |