Class: Aws::KinesisAnalyticsV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KinesisAnalyticsV2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/client.rb
Overview
An API client for KinesisAnalyticsV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KinesisAnalyticsV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_application_cloud_watch_logging_option(params = {}) ⇒ Types::AddApplicationCloudWatchLoggingOptionResponse
Adds an Amazon CloudWatch log stream to monitor application configuration errors.
-
#add_application_input(params = {}) ⇒ Types::AddApplicationInputResponse
Adds a streaming source to your SQL-based Kinesis Data Analytics application.
-
#add_application_input_processing_configuration(params = {}) ⇒ Types::AddApplicationInputProcessingConfigurationResponse
Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application.
-
#add_application_output(params = {}) ⇒ Types::AddApplicationOutputResponse
Adds an external destination to your SQL-based Kinesis Data Analytics application.
-
#add_application_reference_data_source(params = {}) ⇒ Types::AddApplicationReferenceDataSourceResponse
Adds a reference data source to an existing SQL-based Kinesis Data Analytics application.
-
#add_application_vpc_configuration(params = {}) ⇒ Types::AddApplicationVpcConfigurationResponse
Adds a Virtual Private Cloud (VPC) configuration to the application.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a Managed Service for Apache Flink application.
-
#create_application_presigned_url(params = {}) ⇒ Types::CreateApplicationPresignedUrlResponse
Creates and returns a URL that you can use to connect to an application’s extension.
-
#create_application_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the application’s state data.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
-
#delete_application_cloud_watch_logging_option(params = {}) ⇒ Types::DeleteApplicationCloudWatchLoggingOptionResponse
Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application.
-
#delete_application_input_processing_configuration(params = {}) ⇒ Types::DeleteApplicationInputProcessingConfigurationResponse
Deletes an InputProcessingConfiguration from an input.
-
#delete_application_output(params = {}) ⇒ Types::DeleteApplicationOutputResponse
Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application’s configuration.
-
#delete_application_reference_data_source(params = {}) ⇒ Types::DeleteApplicationReferenceDataSourceResponse
Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application’s configuration.
-
#delete_application_snapshot(params = {}) ⇒ Struct
Deletes a snapshot of application state.
-
#delete_application_vpc_configuration(params = {}) ⇒ Types::DeleteApplicationVpcConfigurationResponse
Removes a VPC configuration from a Managed Service for Apache Flink application.
-
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Returns information about a specific Managed Service for Apache Flink application.
-
#describe_application_snapshot(params = {}) ⇒ Types::DescribeApplicationSnapshotResponse
Returns information about a snapshot of application state data.
-
#describe_application_version(params = {}) ⇒ Types::DescribeApplicationVersionResponse
Provides a detailed description of a specified version of the application.
-
#discover_input_schema(params = {}) ⇒ Types::DiscoverInputSchemaResponse
Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object.
-
#list_application_snapshots(params = {}) ⇒ Types::ListApplicationSnapshotsResponse
Lists information about the current application snapshots.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists all the versions for the specified application, including versions that were rolled back.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a list of Managed Service for Apache Flink applications in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of key-value tags assigned to the application.
-
#rollback_application(params = {}) ⇒ Types::RollbackApplicationResponse
Reverts the application to the previous running version.
-
#start_application(params = {}) ⇒ Struct
Starts the specified Managed Service for Apache Flink application.
-
#stop_application(params = {}) ⇒ Struct
Stops the application from processing data.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more key-value tags to a Managed Service for Apache Flink application.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a Managed Service for Apache Flink application.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing Managed Service for Apache Flink application.
-
#update_application_maintenance_configuration(params = {}) ⇒ Types::UpdateApplicationMaintenanceConfigurationResponse
Updates the maintenance configuration of the Managed Service for Apache Flink application.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
419 420 421 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 419 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3092 3093 3094 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3092 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3095 3096 3097 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3095 def errors_module Errors end |
Instance Method Details
#add_application_cloud_watch_logging_option(params = {}) ⇒ Types::AddApplicationCloudWatchLoggingOptionResponse
Adds an Amazon CloudWatch log stream to monitor application configuration errors.
479 480 481 482 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 479 def add_application_cloud_watch_logging_option(params = {}, = {}) req = build_request(:add_application_cloud_watch_logging_option, params) req.send_request() end |
#add_application_input(params = {}) ⇒ Types::AddApplicationInputResponse
Adds a streaming source to your SQL-based Kinesis Data Analytics application.
You can add a streaming source when you create an application, or you can use this operation to add a streaming source after you create an application. For more information, see CreateApplication.
Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.
591 592 593 594 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 591 def add_application_input(params = {}, = {}) req = build_request(:add_application_input, params) req.send_request() end |
#add_application_input_processing_configuration(params = {}) ⇒ Types::AddApplicationInputProcessingConfigurationResponse
Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application. An input processor pre-processes records on the input stream before the application’s SQL code executes. Currently, the only input processor available is [Amazon Lambda].
656 657 658 659 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 656 def add_application_input_processing_configuration(params = {}, = {}) req = build_request(:add_application_input_processing_configuration, params) req.send_request() end |
#add_application_output(params = {}) ⇒ Types::AddApplicationOutputResponse
Adds an external destination to your SQL-based Kinesis Data Analytics application.
If you want Kinesis Data Analytics to deliver data from an in-application stream within your application to an external destination (such as an Kinesis data stream, a Kinesis Data Firehose delivery stream, or an Amazon Lambda function), you add the relevant configuration to your application using this operation. You can configure one or more outputs for your application. Each output configuration maps an in-application stream and an external destination.
You can use one of the output configurations to deliver data from your in-application error stream to an external destination so that you can analyze the errors.
Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.
746 747 748 749 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 746 def add_application_output(params = {}, = {}) req = build_request(:add_application_output, params) req.send_request() end |
#add_application_reference_data_source(params = {}) ⇒ Types::AddApplicationReferenceDataSourceResponse
Adds a reference data source to an existing SQL-based Kinesis Data Analytics application.
Kinesis Data Analytics reads reference data (that is, an Amazon S3 object) and creates an in-application table within your application. In the request, you provide the source (S3 bucket name and object key name), name of the in-application table to create, and the necessary mapping information that describes how data in an Amazon S3 object maps to columns in the resulting in-application table.
842 843 844 845 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 842 def add_application_reference_data_source(params = {}, = {}) req = build_request(:add_application_reference_data_source, params) req.send_request() end |
#add_application_vpc_configuration(params = {}) ⇒ Types::AddApplicationVpcConfigurationResponse
Adds a Virtual Private Cloud (VPC) configuration to the application. Applications can use VPCs to store and access resources securely.
Note the following about VPC configurations for Managed Service for Apache Flink applications:
-
VPC configurations are not supported for SQL applications.
-
When a VPC is added to a Managed Service for Apache Flink application, the application can no longer be accessed from the Internet directly. To enable Internet access to the application, add an Internet gateway to your VPC.
916 917 918 919 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 916 def add_application_vpc_configuration(params = {}, = {}) req = build_request(:add_application_vpc_configuration, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3070 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-kinesisanalyticsv2' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a Managed Service for Apache Flink application. For information about creating a Managed Service for Apache Flink application, see [Creating an Application].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html
1286 1287 1288 1289 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1286 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_application_presigned_url(params = {}) ⇒ Types::CreateApplicationPresignedUrlResponse
Creates and returns a URL that you can use to connect to an application’s extension.
The IAM role or user used to call this API defines the permissions to access the extension. After the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request that attempts to connect to the extension.
You control the amount of time that the URL will be valid using the ‘SessionExpirationDurationInSeconds` parameter. If you do not provide this parameter, the returned URL is valid for twelve hours.
<note markdown=“1”> The URL that you get from a call to CreateApplicationPresignedUrl must be used within 3 minutes to be valid. If you first try to use the URL after the 3-minute limit expires, the service returns an HTTP 403 Forbidden error.
</note>
1341 1342 1343 1344 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1341 def create_application_presigned_url(params = {}, = {}) req = build_request(:create_application_presigned_url, params) req.send_request() end |
#create_application_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the application’s state data.
1367 1368 1369 1370 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1367 def create_application_snapshot(params = {}, = {}) req = build_request(:create_application_snapshot, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the specified application. Managed Service for Apache Flink halts application execution and deletes the application.
1394 1395 1396 1397 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1394 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_application_cloud_watch_logging_option(params = {}) ⇒ Types::DeleteApplicationCloudWatchLoggingOptionResponse
Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application.
1453 1454 1455 1456 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1453 def delete_application_cloud_watch_logging_option(params = {}, = {}) req = build_request(:delete_application_cloud_watch_logging_option, params) req.send_request() end |
#delete_application_input_processing_configuration(params = {}) ⇒ Types::DeleteApplicationInputProcessingConfigurationResponse
Deletes an InputProcessingConfiguration from an input.
1496 1497 1498 1499 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1496 def delete_application_input_processing_configuration(params = {}, = {}) req = build_request(:delete_application_input_processing_configuration, params) req.send_request() end |
#delete_application_output(params = {}) ⇒ Types::DeleteApplicationOutputResponse
Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application’s configuration. Kinesis Data Analytics will no longer write data from the corresponding in-application stream to the external output destination.
1545 1546 1547 1548 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1545 def delete_application_output(params = {}, = {}) req = build_request(:delete_application_output, params) req.send_request() end |
#delete_application_reference_data_source(params = {}) ⇒ Types::DeleteApplicationReferenceDataSourceResponse
Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application’s configuration.
If the application is running, Kinesis Data Analytics immediately removes the in-application table that you created using the AddApplicationReferenceDataSource operation.
1595 1596 1597 1598 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1595 def delete_application_reference_data_source(params = {}, = {}) req = build_request(:delete_application_reference_data_source, params) req.send_request() end |
#delete_application_snapshot(params = {}) ⇒ Struct
Deletes a snapshot of application state.
1626 1627 1628 1629 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1626 def delete_application_snapshot(params = {}, = {}) req = build_request(:delete_application_snapshot, params) req.send_request() end |
#delete_application_vpc_configuration(params = {}) ⇒ Types::DeleteApplicationVpcConfigurationResponse
Removes a VPC configuration from a Managed Service for Apache Flink application.
1678 1679 1680 1681 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1678 def delete_application_vpc_configuration(params = {}, = {}) req = build_request(:delete_application_vpc_configuration, params) req.send_request() end |
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Returns information about a specific Managed Service for Apache Flink application.
If you want to retrieve a list of all applications in your account, use the ListApplications operation.
1828 1829 1830 1831 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1828 def describe_application(params = {}, = {}) req = build_request(:describe_application, params) req.send_request() end |
#describe_application_snapshot(params = {}) ⇒ Types::DescribeApplicationSnapshotResponse
Returns information about a snapshot of application state data.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 1865 def describe_application_snapshot(params = {}, = {}) req = build_request(:describe_application_snapshot, params) req.send_request() end |
#describe_application_version(params = {}) ⇒ Types::DescribeApplicationVersionResponse
Provides a detailed description of a specified version of the application. To see a list of all the versions of an application, invoke the ListApplicationVersions operation.
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
2018 2019 2020 2021 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2018 def describe_application_version(params = {}, = {}) req = build_request(:describe_application_version, params) req.send_request() end |
#discover_input_schema(params = {}) ⇒ Types::DiscoverInputSchemaResponse
Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object. In the response, the operation returns the inferred schema and also the sample records that the operation used to infer the schema.
You can use the inferred schema when configuring a streaming source for your application. When you create an application using the Kinesis Data Analytics console, the console uses this operation to infer a schema and show it in the console user interface.
2101 2102 2103 2104 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2101 def discover_input_schema(params = {}, = {}) req = build_request(:discover_input_schema, params) req.send_request() end |
#list_application_snapshots(params = {}) ⇒ Types::ListApplicationSnapshotsResponse
Lists information about the current application snapshots.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2147 def list_application_snapshots(params = {}, = {}) req = build_request(:list_application_snapshots, params) req.send_request() end |
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists all the versions for the specified application, including versions that were rolled back. The response also includes a summary of the configuration associated with each version.
To get the complete description of a specific application version, invoke the DescribeApplicationVersion operation.
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
2204 2205 2206 2207 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2204 def list_application_versions(params = {}, = {}) req = build_request(:list_application_versions, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a list of Managed Service for Apache Flink applications in your account. For each application, the response includes the application name, Amazon Resource Name (ARN), and status.
If you want detailed information about a specific application, use DescribeApplication.
2256 2257 2258 2259 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2256 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of key-value tags assigned to the application. For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2291 2292 2293 2294 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2291 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#rollback_application(params = {}) ⇒ Types::RollbackApplicationResponse
Reverts the application to the previous running version. You can roll back an application if you suspect it is stuck in a transient status.
You can roll back an application only if it is in the ‘UPDATING` or `AUTOSCALING` status.
When you rollback an application, it loads state data from the last successful snapshot. If the application has no snapshots, Managed Service for Apache Flink rejects the rollback request.
This action is not supported for Managed Service for Apache Flink for SQL applications.
2448 2449 2450 2451 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2448 def rollback_application(params = {}, = {}) req = build_request(:rollback_application, params) req.send_request() end |
#start_application(params = {}) ⇒ Struct
Starts the specified Managed Service for Apache Flink application. After creating an application, you must exclusively call this operation to start your application.
2493 2494 2495 2496 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2493 def start_application(params = {}, = {}) req = build_request(:start_application, params) req.send_request() end |
#stop_application(params = {}) ⇒ Struct
Stops the application from processing data. You can stop an application only if it is in the running status, unless you set the ‘Force` parameter to `true`.
You can use the DescribeApplication operation to find the application status.
Managed Service for Apache Flink takes a snapshot when the application is stopped, unless ‘Force` is set to `true`.
2543 2544 2545 2546 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2543 def stop_application(params = {}, = {}) req = build_request(:stop_application, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more key-value tags to a Managed Service for Apache Flink application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is
-
For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2581 2582 2583 2584 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2581 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a Managed Service for Apache Flink application. For more information, see [Using Tagging].
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html
2613 2614 2615 2616 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2613 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing Managed Service for Apache Flink application. Using this operation, you can update application code, input configuration, and output configuration.
Managed Service for Apache Flink updates the ‘ApplicationVersionId` each time you update your application.
2996 2997 2998 2999 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 2996 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_application_maintenance_configuration(params = {}) ⇒ Types::UpdateApplicationMaintenanceConfigurationResponse
Updates the maintenance configuration of the Managed Service for Apache Flink application.
You can invoke this operation on an application that is in one of the two following states: ‘READY` or `RUNNING`. If you invoke it when the application is in a state other than these two states, it throws a `ResourceInUseException`. The service makes use of the updated configuration the next time it schedules maintenance for the application. If you invoke this operation after the service schedules maintenance, the service will apply the configuration update the next time it schedules maintenance for the application. This means that you might not see the maintenance configuration update applied to the maintenance process that follows a successful invocation of this operation, but to the following maintenance process instead.
To see the current maintenance configuration of your application, invoke the DescribeApplication operation.
For information about application maintenance, see [Managed Service for Apache Flink for Apache Flink Maintenance].
<note markdown=“1”> This operation is supported only for Managed Service for Apache Flink.
</note>
[1]: docs.aws.amazon.com/kinesisanalytics/latest/java/maintenance.html
3061 3062 3063 3064 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3061 def update_application_maintenance_configuration(params = {}, = {}) req = build_request(:update_application_maintenance_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3085 3086 3087 |
# File 'lib/aws-sdk-kinesisanalyticsv2/client.rb', line 3085 def waiter_names [] end |