Class: Aws::KinesisAnalyticsV2::Types::CheckpointConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::CheckpointConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass CheckpointConfiguration data as a hash:
{
configuration_type: "DEFAULT", # required, accepts DEFAULT, CUSTOM
checkpointing_enabled: false,
checkpoint_interval: 1,
min_pause_between_checkpoints: 1,
}
Describes an application's checkpointing configuration. Checkpointing is the process of persisting application state for fault tolerance. For more information, see [ Checkpoints for Fault Tolerance] in the [Apache Flink Documentation].
[1]: ci.apache.org/projects/flink/flink-docs-release-1.8/concepts/programming-model.html#checkpoints-for-fault-tolerance [2]: ci.apache.org/projects/flink/flink-docs-release-1.8/
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checkpoint_interval ⇒ Integer
Describes the interval in milliseconds between checkpoint operations.
-
#checkpointing_enabled ⇒ Boolean
Describes whether checkpointing is enabled for a Flink-based Kinesis Data Analytics application.
-
#configuration_type ⇒ String
Describes whether the application uses Kinesis Data Analytics' default checkpointing behavior.
-
#min_pause_between_checkpoints ⇒ Integer
Describes the minimum time in milliseconds after a checkpoint operation completes that a new checkpoint operation can start.
Instance Attribute Details
#checkpoint_interval ⇒ Integer
Describes the interval in milliseconds between checkpoint operations.
<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `CheckpointInterval` value of 60000, even if this value is set to another value using this API or in application code.
</note>
1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1615 class CheckpointConfiguration < Struct.new( :configuration_type, :checkpointing_enabled, :checkpoint_interval, :min_pause_between_checkpoints) SENSITIVE = [] include Aws::Structure end |
#checkpointing_enabled ⇒ Boolean
Describes whether checkpointing is enabled for a Flink-based Kinesis Data Analytics application.
<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `CheckpointingEnabled` value of `true`, even if this value is set to another value using this API or in application code.
</note>
1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1615 class CheckpointConfiguration < Struct.new( :configuration_type, :checkpointing_enabled, :checkpoint_interval, :min_pause_between_checkpoints) SENSITIVE = [] include Aws::Structure end |
#configuration_type ⇒ String
Describes whether the application uses Kinesis Data Analytics' default checkpointing behavior. You must set this property to `CUSTOM` in order to set the `CheckpointingEnabled`, `CheckpointInterval`, or `MinPauseBetweenCheckpoints` parameters.
<note markdown=“1”> If this value is set to `DEFAULT`, the application will use the following values, even if they are set to other values using APIs or application code:
* **CheckpointingEnabled:** true
-
*CheckpointInterval:* 60000
-
*MinPauseBetweenCheckpoints:* 5000
</note>
1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1615 class CheckpointConfiguration < Struct.new( :configuration_type, :checkpointing_enabled, :checkpoint_interval, :min_pause_between_checkpoints) SENSITIVE = [] include Aws::Structure end |
#min_pause_between_checkpoints ⇒ Integer
Describes the minimum time in milliseconds after a checkpoint operation completes that a new checkpoint operation can start. If a checkpoint operation takes longer than the `CheckpointInterval`, the application otherwise performs continual checkpoint operations. For more information, see [ Tuning Checkpointing] in the [Apache Flink Documentation].
<note markdown=“1”> If `CheckpointConfiguration.ConfigurationType` is `DEFAULT`, the application will use a `MinPauseBetweenCheckpoints` value of 5000, even if this value is set using this API or in application code.
</note>
[1]: ci.apache.org/projects/flink/flink-docs-release-1.8/ops/state/large_state_tuning.html#tuning-checkpointing [2]: ci.apache.org/projects/flink/flink-docs-release-1.8/
1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 1615 class CheckpointConfiguration < Struct.new( :configuration_type, :checkpointing_enabled, :checkpoint_interval, :min_pause_between_checkpoints) SENSITIVE = [] include Aws::Structure end |