Class: Aws::KinesisAnalyticsV2::Types::CustomArtifactConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::CustomArtifactConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass CustomArtifactConfiguration data as a hash:
{
artifact_type: "UDF", # required, accepts UDF, DEPENDENCY_JAR
s3_content_location: {
bucket_arn: "BucketARN", # required
file_key: "FileKey", # required
object_version: "ObjectVersion",
},
maven_reference: {
group_id: "MavenGroupId", # required
artifact_id: "MavenArtifactId", # required
version: "MavenVersion", # required
},
}
Specifies dependency JARs, as well as JAR files that contain user-defined functions (UDF).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
`UDF` stands for user-defined functions.
-
#maven_reference ⇒ Types::MavenReference
The parameters required to fully specify a Maven reference.
-
#s3_content_location ⇒ Types::S3ContentLocation
For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Instance Attribute Details
#artifact_type ⇒ String
`UDF` stands for user-defined functions. This type of artifact must be in an S3 bucket. A `DEPENDENCY_JAR` can be in either Maven or an S3 bucket.
2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 2376 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |
#maven_reference ⇒ Types::MavenReference
The parameters required to fully specify a Maven reference.
2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 2376 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |
#s3_content_location ⇒ Types::S3ContentLocation
For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 2376 class CustomArtifactConfiguration < Struct.new( :artifact_type, :s3_content_location, :maven_reference) SENSITIVE = [] include Aws::Structure end |