Class: Aws::KinesisAnalyticsV2::Types::DeployAsApplicationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::DeployAsApplicationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
When making an API call, you may pass DeployAsApplicationConfiguration data as a hash:
{
s3_content_location: { # required
bucket_arn: "BucketARN", # required
base_path: "BasePath",
},
}
The information required to deploy a Kinesis Data Analytics Studio notebook as an application with durable state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_content_location ⇒ Types::S3ContentBaseLocation
The description of an Amazon S3 object that contains the Amazon Data Analytics application, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
Instance Attribute Details
#s3_content_location ⇒ Types::S3ContentBaseLocation
The description of an Amazon S3 object that contains the Amazon Data Analytics application, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
2803 2804 2805 2806 2807 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 2803 class DeployAsApplicationConfiguration < Struct.new( :s3_content_location) SENSITIVE = [] include Aws::Structure end |