Class: Aws::KinesisAnalyticsV2::Types::FlinkRunConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass FlinkRunConfiguration data as a hash:

{
  allow_non_restored_state: false,
}

Describes the starting parameters for a Flink-based Kinesis Data Analytics application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_non_restored_stateBoolean

When restoring from a snapshot, specifies whether the runtime is allowed to skip a state that cannot be mapped to the new program. This will happen if the program is updated between snapshots to remove stateful parameters, and state data in the snapshot no longer corresponds to valid application data. For more information, see [ Allowing Non-Restored State] in the [Apache Flink documentation].

<note markdown=“1”> This value defaults to `false`. If you update your application without specifying this parameter, `AllowNonRestoredState` will be set to `false`, even if it was previously set to `true`.

</note>

[1]: ci.apache.org/projects/flink/flink-docs-release-1.8/ops/state/savepoints.html#allowing-non-restored-state [2]: ci.apache.org/projects/flink/flink-docs-release-1.8/

Returns:

  • (Boolean)


3337
3338
3339
3340
3341
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 3337

class FlinkRunConfiguration < Struct.new(
  :allow_non_restored_state)
  SENSITIVE = []
  include Aws::Structure
end