Class: Aws::KinesisAnalyticsV2::Types::KinesisStreamsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::KinesisStreamsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Note:
When making an API call, you may pass KinesisStreamsInput data as a hash:
{
resource_arn: "ResourceARN", # required
}
Identifies a Kinesis data stream as the streaming source. You provide the stream's Amazon Resource Name (ARN).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the input Kinesis data stream to read.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the input Kinesis data stream to read.
4214 4215 4216 4217 4218 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4214 class KinesisStreamsInput < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |