Class: Aws::KinesisAnalyticsV2::Types::MonitoringConfigurationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass MonitoringConfigurationUpdate data as a hash:

{
  configuration_type_update: "DEFAULT", # accepts DEFAULT, CUSTOM
  metrics_level_update: "APPLICATION", # accepts APPLICATION, TASK, OPERATOR, PARALLELISM
  log_level_update: "INFO", # accepts INFO, WARN, ERROR, DEBUG
}

Describes updates to configuration parameters for Amazon CloudWatch logging for an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_type_updateString

Describes updates to whether to use the default CloudWatch logging configuration for an application. You must set this property to `CUSTOM` in order to set the `LogLevel` or `MetricsLevel` parameters.

Returns:

  • (String)


4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4845

class MonitoringConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :metrics_level_update,
  :log_level_update)
  SENSITIVE = []
  include Aws::Structure
end

#log_level_updateString

Describes updates to the verbosity of the CloudWatch Logs for an application.

Returns:

  • (String)


4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4845

class MonitoringConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :metrics_level_update,
  :log_level_update)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_level_updateString

Describes updates to the granularity of the CloudWatch Logs for an application. The `Parallelism` level is not recommended for applications with a Parallelism over 64 due to excessive costs.

Returns:

  • (String)


4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4845

class MonitoringConfigurationUpdate < Struct.new(
  :configuration_type_update,
  :metrics_level_update,
  :log_level_update)
  SENSITIVE = []
  include Aws::Structure
end