Class: Aws::KinesisAnalyticsV2::Types::S3ContentLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisanalyticsv2/types.rb

Overview

Note:

When making an API call, you may pass S3ContentLocation data as a hash:

{
  bucket_arn: "BucketARN", # required
  file_key: "FileKey", # required
  object_version: "ObjectVersion",
}

For a Kinesis Data Analytics application provides a description of an Amazon S3 object, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_arnString

The Amazon Resource Name (ARN) for the S3 bucket containing the application code.

Returns:

  • (String)


5844
5845
5846
5847
5848
5849
5850
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5844

class S3ContentLocation < Struct.new(
  :bucket_arn,
  :file_key,
  :object_version)
  SENSITIVE = []
  include Aws::Structure
end

#file_keyString

The file key for the object containing the application code.

Returns:

  • (String)


5844
5845
5846
5847
5848
5849
5850
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5844

class S3ContentLocation < Struct.new(
  :bucket_arn,
  :file_key,
  :object_version)
  SENSITIVE = []
  include Aws::Structure
end

#object_versionString

The version of the object containing the application code.

Returns:

  • (String)


5844
5845
5846
5847
5848
5849
5850
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 5844

class S3ContentLocation < Struct.new(
  :bucket_arn,
  :file_key,
  :object_version)
  SENSITIVE = []
  include Aws::Structure
end