Class: Aws::KinesisAnalyticsV2::Types::StopApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisAnalyticsV2::Types::StopApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisanalyticsv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the running application to stop.
-
#force ⇒ Boolean
Set to `true` to force the application to stop.
Instance Attribute Details
#application_name ⇒ String
The name of the running application to stop.
4512 4513 4514 4515 4516 4517 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4512 class StopApplicationRequest < Struct.new( :application_name, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Set to `true` to force the application to stop. If you set `Force` to `true`, Kinesis Data Analytics stops the application without taking a snapshot.
<note markdown=“1”> Force-stopping your application may lead to data loss or duplication. To prevent data loss or duplicate processing of data during application restarts, we recommend you to take frequent snapshots of your application.
</note>
You can only force stop a Flink-based Kinesis Data Analytics application. You can't force stop a SQL-based Kinesis Data Analytics application.
The application must be in the `STARTING`, `UPDATING`, `STOPPING`, `AUTOSCALING`, or `RUNNING` status.
4512 4513 4514 4515 4516 4517 |
# File 'lib/aws-sdk-kinesisanalyticsv2/types.rb', line 4512 class StopApplicationRequest < Struct.new( :application_name, :force) SENSITIVE = [] include Aws::Structure end |